<a href="https://github.com/AidenEllis/Cligo"><p align="center"></a>
<img height=100 src="https://upstorage.pythonanywhere.com/api/storage/file/its_sakib/Public/Github/PainlessDB/pldb_1_320.png"/>


<p align="center">
  <strong>PainlessDB - Taking Your Pain away to the moon 🚀</strong>
</p>

<h3 align="center">
  <a href="https://github.com/AidenEllis/PainlessDB/blob/main/CONTRIBUTING.md">Contribute</a>
  <span> · </span>
  <a href="https://discord.gg/aw35Kb7uE7">Community</a>
  <span> · </span>
  <a href="https://github.com/AidenEllis/PainlessDB/tree/main/docs">Documentation</a>
</h3>

---

## 🎫 Introduction :
PainlessDB is a Python-based free and open-source Database. PainlessDB makes 
it really easy when it comes to basic database operations like 
`['Create', 'Get', 'Update', 'Delete']` and a Really easy way to create your 
Database Schema.

It's really easy and Simple to get started with your database. Just create your 
Database Schema and enjoy your new database.

The whole purpose of creating this Database was to make it really easy to do Database 
stuffs when you need it, maybe you need it in a specific situation where you don't 
want to do all those geeky stuffs just to create and do some simple database tasks.

✅ `Easy & Simple to Understand and Implement`

✅ `Easy to build your database Schema`

✅ `Core database Functionalities: [Get, Create, update, Delete]`

✅ `Supports multiple Datatypes [str, int, float, bool, list, dict, datetime.datetime]`

✅ `Searching/Query Functionality`

Read The [Docs](https://github.com/AidenEllis/PainlessDB/tree/main/docs) To quickly get Started! 🍰

With our continuous updates you will keep getting new features and bug fixes.

## How to install?
`via pip (recommended) :`
```commandline
pip install PainlessDB
```

or

`via pip + github:`
```commandline
pip install git+https://github.com/AidenEllis/PainlessDB.git
```

or

```
Download this repo and use it.
```

## Contributions

PainlessDB is open to contributions.

Please read [CONTRIBUTING.md](https://github.com/AidenEllis/Cligo/blob/main/CONTRIBUTING.md) for details on this project.

## Code of Conduct

Please read [CODE_OF_CONDUCT.md](https://github.com/AidenEllis/Cligo/blob/main//CODE_OF_CONDUCT.md) for details on our code of conduct.
